1. Installation — Django-tornado-websockets 0.0.7 documentation

# 1. Installation

## 1.1. Automatic installation

Note

Automatic installation is not already working, please see Manual installation section.

    $ pip install django-tornado-websockets

## 1.2. Manual installation

Clone this repo and run installation with `pip` or `setup.py install`:

    $ git clone https://github.com/Kocal/django-tornado-websockets.git
    $ cd django-tornado-websockets
    # Installation with pip
    $ pip install -e .
    # or with setup.py
    $ python setup.py install